@@ -5,16 +5,10 @@ import pathlib
 def get_extensions_set(current_dir) -> set:
     # ゴミ箱送りファイルの拡張子リストを取得
 
-    def _file_not_found_process():
-        print(f'The {EXTENSION_FILE} file could not be found.')
-        print('Please create.')
-
     EXTENSION_FILE = '.rmoutrc'
     home_dir = pathlib.Path.home()
     extfile_in_curr = os.path.join(current_dir, EXTENSION_FILE)
     extfile_in_home = os.path.join(home_dir, EXTENSION_FILE)
-    print(extfile_in_curr)
-    print(extfile_in_home)
 
     target_ext_list = []
     if os.path.isfile(extfile_in_home):
@@ -60,4 +54,5 @@ def extract_files_by_extlist(target_ext_set, current_dir) -> list:
         _std_out(throwaway)
         return throwaway
     else:
-        return throwaway
+        print('The file to be deleted cannot be found.')
+        return list()
